@@ -5,13 +5,13 @@ import (
 )
 
 type QueryError struct {
-	Err           error                  `json:"-"` // Err holds underlying if available
-	Message       string                 `json:"message"`
-	Locations     []Location             `json:"locations,omitempty"`
-	Path          []interface{}          `json:"path,omitempty"`
-	Rule          string                 `json:"-"`
-	ResolverError error                  `json:"-"`
-	Extensions    map[string]interface{} `json:"extensions,omitempty"`
+	Err           error          `json:"-"` // Err holds underlying if available
+	Message       string         `json:"message"`
+	Locations     []Location     `json:"locations,omitempty"`
+	Path          []any          `json:"path,omitempty"`
+	Rule          string         `json:"-"`
+	ResolverError error          `json:"-"`
+	Extensions    map[string]any `json:"extensions,omitempty"`
 }
 
 type Location struct {
@@ -23,7 +23,7 @@ func (a Location) Before(b Location) bool {
 	return a.Line < b.Line || (a.Line == b.Line && a.Column < b.Column)
 }
 
-func Errorf(format string, a ...interface{}) *QueryError {
+func Errorf(format string, a ...any) *QueryError {
 	// similar to fmt.Errorf, Errorf will wrap the last argument if it is an instance of error
 	var err error
 	if n := len(a); n > 0 {
