@@ -496,7 +496,7 @@ func (r *starshipResolver) Length(args struct{ Unit string }) float64 {
 }
 
 type searchResultResolver struct {
-	result interface{}
+	result any
 }
 
 func (r *searchResultResolver) ToHuman() (*humanResolver, bool) {
@@ -579,10 +579,7 @@ func newFriendsConnectionResolver(ids []graphql.ID, args friendsConnectionArgs)
 
 	to := len(ids)
 	if args.First != nil {
-		to = from + int(*args.First)
-		if to > len(ids) {
-			to = len(ids)
-		}
+		to = min(from+int(*args.First), len(ids))
 	}
 
 	return &friendsConnectionResolver{
@@ -620,7 +617,7 @@ func (r *friendsConnectionResolver) PageInfo() *pageInfoResolver {
 }
 
 func encodeCursor(i int) graphql.ID {
-	return graphql.ID(base64.StdEncoding.EncodeToString([]byte(fmt.Sprintf("cursor%d", i+1))))
+	return graphql.ID(base64.StdEncoding.EncodeToString(fmt.Appendf(nil, "cursor%d", i+1)))
 }
 
 type friendsEdgeResolver struct {
