@@ -73,7 +73,7 @@ func (r *Request) Subscribe(ctx context.Context, s *resolvable.Schema, op *ast.O
 		if _, nonNullChild := f.field.Type.(*ast.NonNull); nonNullChild {
 			return sendAndReturnClosed(&Response{Errors: []*errors.QueryError{err}})
 		}
-		return sendAndReturnClosed(&Response{Data: []byte(fmt.Sprintf(`{"%s":null}`, f.field.Alias)), Errors: []*errors.QueryError{err}})
+		return sendAndReturnClosed(&Response{Data: fmt.Appendf(nil, `{"%s":null}`, f.field.Alias), Errors: []*errors.QueryError{err}})
 	}
 
 	if ctxErr := ctx.Err(); ctxErr != nil {
@@ -119,9 +119,12 @@ func (r *Request) Subscribe(ctx context.Context, s *resolvable.Schema, op *ast.O
 						Vars:   r.Vars,
 						Schema: r.Schema,
 					},
-					Limiter: r.Limiter,
-					Tracer:  r.Tracer,
-					Logger:  r.Logger,
+					Limiter:                 r.Limiter,
+					Tracer:                  r.Tracer,
+					Logger:                  r.Logger,
+					DisableMemoryPooling:    r.DisableMemoryPooling,
+					MaxPooledBufferCapacity: r.MaxPooledBufferCapacity,
+					PanicHandler:            r.PanicHandler,
 				}
 				var out bytes.Buffer
 				func() {
