@@ -19,7 +19,7 @@ import (
 // If the context gets cancelled, the response channel will be closed and no
 // further resolvers will be called. The context error will be returned as soon
 // as possible (not immediately).
-func (s *Schema) Subscribe(ctx context.Context, queryString string, operationName string, variables map[string]interface{}) (<-chan interface{}, error) {
+func (s *Schema) Subscribe(ctx context.Context, queryString string, operationName string, variables map[string]any) (<-chan any, error) {
 	if !s.res.SubscriptionResolver.IsValid() {
 		return nil, errors.New("schema created without resolver, can not subscribe")
 	}
@@ -29,7 +29,7 @@ func (s *Schema) Subscribe(ctx context.Context, queryString string, operationNam
 	return s.subscribe(ctx, queryString, operationName, variables, s.res), nil
 }
 
-func (s *Schema) subscribe(ctx context.Context, queryString string, operationName string, variables map[string]interface{}, res *resolvable.Schema) <-chan interface{} {
+func (s *Schema) subscribe(ctx context.Context, queryString string, operationName string, variables map[string]any, res *resolvable.Schema) <-chan any {
 	doc, qErr := query.Parse(queryString)
 	if qErr != nil {
 		return sendAndReturnClosed(&Response{Errors: []*qerrors.QueryError{qErr}})
@@ -58,6 +58,8 @@ func (s *Schema) subscribe(ctx context.Context, queryString string, operationNam
 		Logger:                   s.logger,
 		PanicHandler:             s.panicHandler,
 		SubscribeResolverTimeout: s.subscribeResolverTimeout,
+		DisableMemoryPooling:     s.disableMemoryPooling,
+		MaxPooledBufferCapacity:  s.maxPooledBufferCapacity,
 	}
 	varTypes := make(map[string]*introspection.Type)
 	for _, v := range op.Vars {
@@ -74,7 +76,7 @@ func (s *Schema) subscribe(ctx context.Context, queryString string, operationNam
 	}
 
 	responses := r.Subscribe(ctx, res, op)
-	c := make(chan interface{})
+	c := make(chan any)
 	go func() {
 	Loop:
 		for resp := range responses {
@@ -92,8 +94,8 @@ func (s *Schema) subscribe(ctx context.Context, queryString string, operationNam
 	return c
 }
 
-func sendAndReturnClosed(resp *Response) chan interface{} {
-	c := make(chan interface{}, 1)
+func sendAndReturnClosed(resp *Response) chan any {
+	c := make(chan any, 1)
 	c <- resp
 	close(c)
 	return c
